@@ -3,6 +3,9 @@ socket_urls = {
     'derivatives_realtime': {
         'trades': "wss://dataservices.btgpactualsolutions.com/stream/v2/marketdata/trade/derivatives",
         'books': "wss://dataservices.btgpactualsolutions.com/stream/v2/marketdata/book/derivatives",
+        'candles-1S': "wss://dataservices.btgpactualsolutions.com/stream/v1/marketdata/candles/1S/derivatives",
+        'candles-1M': "wss://dataservices.btgpactualsolutions.com/stream/v1/marketdata/candles/1M/derivatives",
+        'stoploss': "wss://dataservices.btgpactualsolutions.com/stream/v1/marketdata/stoploss/derivatives",
     },
     'derivatives_delayed': {
         'trades': "wss://dataservices.btgpactualsolutions.com/stream/v2/marketdata/trade/derivatives/delayed",
@@ -10,6 +13,8 @@ socket_urls = {
     'stocks_realtime': {
         'trades': "wss://dataservices.btgpactualsolutions.com/stream/v2/marketdata/trade/stocks",
         'books': "wss://dataservices.btgpactualsolutions.com/stream/v2/marketdata/book/stocks",
+        'candles-1S': "wss://dataservices.btgpactualsolutions.com/stream/v1/marketdata/candles/1S/stocks",
+        'candles-1M': "wss://dataservices.btgpactualsolutions.com/stream/v1/marketdata/candles/1M/stocks",
         'stoploss': "wss://dataservices.btgpactualsolutions.com/stream/v1/marketdata/stoploss/stocks",
     },
     'stocks_delayed': {
@@ -32,4 +37,5 @@ def valid_ws_options(feed, target):
 MAX_WS_RECONNECT_RETRIES = 5
 
 ### Rest
-url_apis = "https://dataservices.btgpactualsolutions.com/api/v2"
\ No newline at end of file
+url_apis = "https://dataservices.btgpactualsolutions.com/api/v2"
+url_api_v1 = "https://dataservices.btgpactualsolutions.com/api/v1"
\ No newline at end of file
